==> telescope.1.4.zip: 3rdparty/webcore/platform/graphics/texmap/TextureMapperTelescope.h <==
/*
 * Copyright (C) 2020 Activision Publishing, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials
 *    provided with the distribution.
 *
 * 3. Neither the name of Activision Publishing, Inc. nor the names of
 *    its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#pragma once
#if USE(TEXTURE_MAPPER_TELESCOPE)
#include "ClipStack.h"
#include "TextureMapper.h"

namespace Telescope
{
	class HardwareSurfaceBase;
	class HardwareRenderBase;
}

namespace WebCore
{
class TextureMapperTelescope : public TextureMapper
{
   public:
	TextureMapperTelescope(Telescope::HardwareRenderBase& render);
	virtual ~TextureMapperTelescope();

	static TextureMapperTelescope* create(Telescope::HardwareRenderBase& render);

	// TextureMapper implementations
	void drawBorder(const Color&, float borderWidth, const FloatRect&, const TransformationMatrix&) override;
	void drawNumber(int number, const Color&, const FloatPoint&, const TransformationMatrix&) override;

	void drawTexture(const BitmapTexture&,
					 const FloatRect& target,
					 const TransformationMatrix& modelViewMatrix = TransformationMatrix(),
					 float opacity = 1.0f,
					 unsigned exposedEdges = AllEdges) override;
	void drawSolidColor(const FloatRect&, const TransformationMatrix&, const Color&, bool) override;
	void clearColor(const Color&) override;

	void bindSurface(BitmapTexture* inSurface) override;

	void beginClip(const TransformationMatrix&, const FloatRect&) override;
	void beginPainting(PaintFlags /* = 0 */) override;
	void endPainting() override;
	void endClip() override;
	IntRect clipBounds() override;
	IntSize maxTextureSize() const override { return IntSize(2000, 2000); };

	Ref<BitmapTexture> createTexture() override;
	Ref<BitmapTexture> createTexture(int internalFormat) override;
	Ref<BitmapTexture> createRenderTarget() override;

	void setViewSize(const IntSize& viewSize);

   private:
	ClipStack& clipStack();

	bool beginScissorClip(const TransformationMatrix&, const FloatRect&);
	void bindDefaultSurface();
	void initializeStencil();

	Telescope::HardwareRenderBase& m_render;
	RefPtr<BitmapTexture> m_currentSurface;
	Telescope::HardwareSurfaceBase* m_defaultSurface = nullptr;

	ClipStack m_clipStack;
	bool m_didModifyStencil = false;
	IntSize m_viewSize;
};
}  // namespace WebCore
#endif	// USE(TEXTURE_MAPPER_TELESCOPE)

==> telescope.1.15.zip: 3rdparty/webcore/platform/graphics/texmap/TextureMapperTelescope.h <==
/*
 * Copyright (C) 2020 Activision Publishing, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials
 *    provided with the distribution.
 *
 * 3. Neither the name of Activision Publishing, Inc. nor the names of
 *    its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#pragma once
#if USE(TEXTURE_MAPPER_TELESCOPE)
#include "ClipStack.h"
#include "TextureMapper.h"

namespace Telescope
{
	class HardwareSurfaceBase;
	class HardwareRenderBase;
}

namespace WebCore
{
class TextureMapperTelescope : public TextureMapper
{
   public:
	TextureMapperTelescope(Telescope::HardwareRenderBase& render);
	virtual ~TextureMapperTelescope();

	static TextureMapperTelescope* create(Telescope::HardwareRenderBase& render);

	// TextureMapper implementations
	void drawBorder(const Color&, float borderWidth, const FloatRect&, const TransformationMatrix&) override;
	void drawNumber(int number, const Color&, const FloatPoint&, const TransformationMatrix&) override;

	void drawTexture(const BitmapTexture&,
					 const FloatRect& target,
					 const TransformationMatrix& modelViewMatrix = TransformationMatrix(),
					 float opacity = 1.0f,
					 unsigned exposedEdges = AllEdges) override;
	void drawSolidColor(const FloatRect&, const TransformationMatrix&, const Color&, bool) override;
	void clearColor(const Color&) override;

	void bindSurface(BitmapTexture* inSurface) override;

	void beginClip(const TransformationMatrix&, const FloatRect&) override;
	void beginPainting(PaintFlags /* = 0 */) override;
	void endPainting() override;
	void endClip() override;
	IntRect clipBounds() override;
	IntSize maxTextureSize() const override { return IntSize(1920, 1080); };

	Ref<BitmapTexture> createTexture() override;
	Ref<BitmapTexture> createTexture(int internalFormat) override;
	Ref<BitmapTexture> createRenderTarget() override;

	virtual void drawVideo(const FloatRect& target, const FloatRect& source) override;
	virtual bool PrepareTex2DSubData(const IntRect&) override;
	void setViewSize(const IntSize& viewSize);

   private:
	ClipStack& clipStack();

	bool beginScissorClip(const TransformationMatrix&, const FloatRect&);
	void bindDefaultSurface();
	void initializeStencil();

	Telescope::HardwareRenderBase& m_render;
	RefPtr<BitmapTexture> m_currentSurface;
	Telescope::HardwareSurfaceBase* m_defaultSurface = nullptr;

	ClipStack m_clipStack;
	bool m_didModifyStencil = false;
	IntSize m_viewSize;
};
}  // namespace WebCore
#endif	// USE(TEXTURE_MAPPER_TELESCOPE)
